@@ -54,6 +54,11 @@ if ($backports_list =~ /^$/) {
     $backports = 0;;
 }
 
+my $disktype = read_env('DISKTYPE', "");
+if ($disktype =~ /^$/) {
+    die "make_disc_trees.pl: DISKTYPE not set, aborting\n";
+}
+
 # MAXCDS is the hard limit on the MAXIMUM number of images to
 # make. MAXJIGDOS and MAXISOS can only make this number smaller; we
 # will use the higher of those 2 numbers as the last image to go to,
@@ -123,7 +128,6 @@ my $blocksize = 2048;
 my ($maxdiskblocks, $diskdesc);
 my $cddir;
 
-my $disktype = $ENV{'DISKTYPE'};
 my $size_swap_check;
 my $hfs_extra = 0;
 my $hfs_mult = 1;
@@ -203,9 +207,8 @@ while (defined (my $pkg = <INLIST>)) {
             $mkisofs_opts = "";
         }
         if ($disknum <= $maxjigdos) {
-            $mkisofs_opts = "$mkisofs_opts -jigdo-jigdo /dev/null";
-            $mkisofs_opts = "$mkisofs_opts -jigdo-template /dev/null";
-            $mkisofs_opts = "$mkisofs_opts -md5-list /dev/null";
+	    # Set things to /dev/null - we're only doing a
+	    # sizing run here
             $mkisofs_opts = "$mkisofs_opts -o /dev/null";
         }
         if ( -e "$bdir/$disknum.mkisofs_dirs" ) {
@@ -655,6 +658,7 @@ sub recompress {
 		! ($filename =~ m/\/.*\/i18n\/(Translation.*gz)$/o)) {
 		system("rm -f $_.gz");
 		system("gzip -9c < $_ >$_.gz");
+		system("rm -f $_");
 	}
 }	
 
@@ -766,6 +770,8 @@ sub get_disc_size {
         $maxdiskblocks = $ENV{'CUSTOMSIZE'} - $reserved || 
             die "Need to specify a custom size for the CUSTOM disktype\n";
         $diskdesc = "User-supplied size";
+    } else {
+	die "make_disc_trees.pl: Unknown disk type \"$chosen_disk\" specified; ABORT\n";
     }
 
     $ENV{'MAXDISKBLOCKS'} = $maxdiskblocks;
@@ -1082,6 +1088,7 @@ sub add_trans_desc_entry {
                 # so, we'll need to uncompress again on entry here.
 
                 if (-f "$trans_file.gz") {
+                    system("rm -f $trans_file");
                     system("gunzip $trans_file.gz");
                 }
 
@@ -1253,6 +1260,7 @@ sub remove_trans_desc_entry {
             # Keeping files in .gz format is expensive - see comment
             # in add_trans_desc_entry() above.
             if (-f "$trans_file.gz") {
+                system("rm -f $trans_file");
                 system("gunzip $trans_file.gz");
             }
             $st = stat("$trans_file") || die "unable to stat $trans_file\n";
